RED = 'red'
PINK = 'pink'
PURPLE = 'purple'
DEEPPURPLE = 'deep_purple'
INDIGO = 'indigo'
BLUE = 'blue'
LIGHTBLUE = 'light_blue'
CYAN = 'cyan'
TEAL = 'teal'
GREEN = 'green'
LIGHTGREEN = 'light_green'
LIME = 'lime'
YELLOW = 'yellow'
AMBER = 'amber'
ORANGE = 'orange'
DEEPORANGE = 'deep_orange'
BROWN = 'brown'
BLUEGREY = 'blue_grey'
GREY = 'grey'
