from dataclasses import dataclass


@dataclass
class Card:
    base: str
    lighten_5: str
    lighten_4: str
    lighten_3: str
    lighten_2: str
    lighten_1: str
    darken_1: str
    darken_2: str
    darken_3: str
    darken_4: str
    accent_1: str
    accent_2: str
    accent_3: str
    accent_4: str
