from .convert import \
    hex_hsl, hex_int, hex_rgb, \
    hsl_hex, hsl_rgb, \
    rgb_hex, rgb_hsl, rgb_int
from palett.fluo import \
    fluo_vector, \
    fluo_entries, \
    fluo_matrix, fluo_rowwise, fluo_columnwise, fluo_pointwise
from palett.tabular import palett_crostab
from palett.flopper import palett_flopper
from palett.dye import DyeFactory, dye
from palett.projector import ProjectorFactory, projector
