BOLD = '1'
ITALIC = '3'
UNDERLINE = '4'
INVERSE = '7'
CLR_BOLD = '22'
CLR_ITALIC = '23'
CLR_UNDERLINE = '24'
CLR_INVERSE = '27'

Effects = {
    'bold': (BOLD, CLR_BOLD),
    'italic': (ITALIC, CLR_ITALIC),
    'underline': (UNDERLINE, CLR_UNDERLINE),
    'inverse': (INVERSE, CLR_INVERSE),
}
