from palett.structs import Card

grey = Card(
    base='#9E9E9E',
    lighten_5='#FAFAFA',
    lighten_4='#F5F5F5',
    lighten_3='#EEEEEE',
    lighten_2='#E0E0E0',
    lighten_1='#BDBDBD',
    darken_1='#757575',
    darken_2='#616161',
    darken_3='#424242',
    darken_4='#212121',
    accent_1='#C4C4C4',
    accent_2='#9E9E9E',
    accent_3='#858585',
    accent_4='#6B6B6B',
)
