from palett.enum.color_cards import \
    RED, PINK, \
    PURPLE, DEEPPURPLE, \
    INDIGO, BLUE, LIGHTBLUE, CYAN, \
    TEAL, GREEN, \
    LIGHTGREEN, LIME, YELLOW, \
    AMBER, ORANGE, DEEPORANGE, \
    BROWN, BLUEGREY, GREY

red = [RED, PINK, ]
purple = [PURPLE, DEEPPURPLE, ]
blue = [INDIGO, BLUE, LIGHTBLUE, CYAN, ]
green = [TEAL, GREEN, ]
yellow_green = [LIGHTGREEN, LIME, YELLOW, ]
orange = [AMBER, ORANGE, DEEPORANGE, ]
grey = [BROWN, BLUEGREY, GREY]
rainbow = red + purple + blue + grey + green + yellow_green + orange
entire = rainbow + grey
