from palett.structs import Card

deep_orange = Card(
    base='#FF5722',
    lighten_5='#FBE9E7',
    lighten_4='#FFCCBC',
    lighten_3='#FFAB91',
    lighten_2='#FF8A65',
    lighten_1='#FF7043',
    darken_1='#F4511E',
    darken_2='#E64A19',
    darken_3='#D84315',
    darken_4='#BF360C',
    accent_1='#FF9E80',
    accent_2='#FF6E40',
    accent_3='#FF3D00',
    accent_4='#DD2C00'
)
