from palett.structs import Card

cyan = Card(
    base='#00BCD4',
    lighten_5='#E0F7FA',
    lighten_4='#B2EBF2',
    lighten_3='#80DEEA',
    lighten_2='#4DD0E1',
    lighten_1='#26C6DA',
    darken_1='#00ACC1',
    darken_2='#0097A7',
    darken_3='#00838F',
    darken_4='#006064',
    accent_1='#84FFFF',
    accent_2='#18FFFF',
    accent_3='#00E5FF',
    accent_4='#00B8D4'
)
