from .amber import amber
from .blue import blue
from .blue_grey import blue_grey
from .brown import brown
from .cyan import cyan
from .deep_orange import deep_orange
from .deep_purple import deep_purple
from .green import green
from .grey import grey
from .indigo import indigo
from .light_blue import light_blue
from .light_green import light_green
from .lime import lime
from .orange import orange
from .pink import pink
from .purple import purple
from .red import red
from .teal import teal
from .yellow import yellow
